# File generated from our OpenAPI spec by Stainless.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from openai import OpenAI, AsyncOpenAI
from tests.utils import assert_matches_type
from openai.pagination import SyncCursorPage, AsyncCursorPage
from openai.types.beta.threads.messages import MessageFile

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestFiles:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    def test_method_retrieve(self, client: OpenAI) -> None:
        file = client.beta.threads.messages.files.retrieve(
            "file-abc123",
            thread_id="thread_abc123",
            message_id="msg_abc123",
        )
        assert_matches_type(MessageFile, file, path=["response"])

    @parametrize
    def test_raw_response_retrieve(self, client: OpenAI) -> None:
        response = client.beta.threads.messages.files.with_raw_response.retrieve(
            "file-abc123",
            thread_id="thread_abc123",
            message_id="msg_abc123",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        file = response.parse()
        assert_matches_type(MessageFile, file, path=["response"])

    @parametrize
    def test_streaming_response_retrieve(self, client: OpenAI) -> None:
        with client.beta.threads.messages.files.with_streaming_response.retrieve(
            "file-abc123",
            thread_id="thread_abc123",
            message_id="msg_abc123",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            file = response.parse()
            assert_matches_type(MessageFile, file, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_retrieve(self, client: OpenAI) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `thread_id` but received ''"):
            client.beta.threads.messages.files.with_raw_response.retrieve(
                "file-abc123",
                thread_id="",
                message_id="msg_abc123",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `message_id` but received ''"):
            client.beta.threads.messages.files.with_raw_response.retrieve(
                "file-abc123",
                thread_id="thread_abc123",
                message_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `file_id` but received ''"):
            client.beta.threads.messages.files.with_raw_response.retrieve(
                "",
                thread_id="thread_abc123",
                message_id="msg_abc123",
            )

    @parametrize
    def test_method_list(self, client: OpenAI) -> None:
        file = client.beta.threads.messages.files.list(
            "string",
            thread_id="string",
        )
        assert_matches_type(SyncCursorPage[MessageFile], file, path=["response"])

    @parametrize
    def test_method_list_with_all_params(self, client: OpenAI) -> None:
        file = client.beta.threads.messages.files.list(
            "string",
            thread_id="string",
            after="string",
            before="string",
            limit=0,
            order="asc",
        )
        assert_matches_type(SyncCursorPage[MessageFile], file, path=["response"])

    @parametrize
    def test_raw_response_list(self, client: OpenAI) -> None:
        response = client.beta.threads.messages.files.with_raw_response.list(
            "string",
            thread_id="string",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        file = response.parse()
        assert_matches_type(SyncCursorPage[MessageFile], file, path=["response"])

    @parametrize
    def test_streaming_response_list(self, client: OpenAI) -> None:
        with client.beta.threads.messages.files.with_streaming_response.list(
            "string",
            thread_id="string",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            file = response.parse()
            assert_matches_type(SyncCursorPage[MessageFile], file, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    def test_path_params_list(self, client: OpenAI) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `thread_id` but received ''"):
            client.beta.threads.messages.files.with_raw_response.list(
                "string",
                thread_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `message_id` but received ''"):
            client.beta.threads.messages.files.with_raw_response.list(
                "",
                thread_id="string",
            )


class TestAsyncFiles:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @parametrize
    async def test_method_retrieve(self, async_client: AsyncOpenAI) -> None:
        file = await async_client.beta.threads.messages.files.retrieve(
            "file-abc123",
            thread_id="thread_abc123",
            message_id="msg_abc123",
        )
        assert_matches_type(MessageFile, file, path=["response"])

    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncOpenAI) -> None:
        response = await async_client.beta.threads.messages.files.with_raw_response.retrieve(
            "file-abc123",
            thread_id="thread_abc123",
            message_id="msg_abc123",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        file = response.parse()
        assert_matches_type(MessageFile, file, path=["response"])

    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncOpenAI) -> None:
        async with async_client.beta.threads.messages.files.with_streaming_response.retrieve(
            "file-abc123",
            thread_id="thread_abc123",
            message_id="msg_abc123",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            file = await response.parse()
            assert_matches_type(MessageFile, file, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncOpenAI) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `thread_id` but received ''"):
            await async_client.beta.threads.messages.files.with_raw_response.retrieve(
                "file-abc123",
                thread_id="",
                message_id="msg_abc123",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `message_id` but received ''"):
            await async_client.beta.threads.messages.files.with_raw_response.retrieve(
                "file-abc123",
                thread_id="thread_abc123",
                message_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `file_id` but received ''"):
            await async_client.beta.threads.messages.files.with_raw_response.retrieve(
                "",
                thread_id="thread_abc123",
                message_id="msg_abc123",
            )

    @parametrize
    async def test_method_list(self, async_client: AsyncOpenAI) -> None:
        file = await async_client.beta.threads.messages.files.list(
            "string",
            thread_id="string",
        )
        assert_matches_type(AsyncCursorPage[MessageFile], file, path=["response"])

    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncOpenAI) -> None:
        file = await async_client.beta.threads.messages.files.list(
            "string",
            thread_id="string",
            after="string",
            before="string",
            limit=0,
            order="asc",
        )
        assert_matches_type(AsyncCursorPage[MessageFile], file, path=["response"])

    @parametrize
    async def test_raw_response_list(self, async_client: AsyncOpenAI) -> None:
        response = await async_client.beta.threads.messages.files.with_raw_response.list(
            "string",
            thread_id="string",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        file = response.parse()
        assert_matches_type(AsyncCursorPage[MessageFile], file, path=["response"])

    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncOpenAI) -> None:
        async with async_client.beta.threads.messages.files.with_streaming_response.list(
            "string",
            thread_id="string",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            file = await response.parse()
            assert_matches_type(AsyncCursorPage[MessageFile], file, path=["response"])

        assert cast(Any, response.is_closed) is True

    @parametrize
    async def test_path_params_list(self, async_client: AsyncOpenAI) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `thread_id` but received ''"):
            await async_client.beta.threads.messages.files.with_raw_response.list(
                "string",
                thread_id="",
            )

        with pytest.raises(ValueError, match=r"Expected a non-empty value for `message_id` but received ''"):
            await async_client.beta.threads.messages.files.with_raw_response.list(
                "",
                thread_id="string",
            )



"""Script that exits 1 if the current environment is not
in sync with the `requirements-dev.lock` file.
"""

from pathlib import Path

import importlib_metadata


def should_run_sync() -> bool:
    dev_lock = Path(__file__).parent.parent.joinpath("requirements-dev.lock")

    for line in dev_lock.read_text().splitlines():
        if not line or line.startswith("#") or line.startswith("-e"):
            continue

        dep, lock_version = line.split("==")

        try:
            version = importlib_metadata.version(dep)

            if lock_version != version:
                print(f"mismatch for {dep} current={version} lock={lock_version}")
                return True
        except Exception:
            print(f"could not import {dep}")
            return True

    return False


def main() -> None:
    if should_run_sync():
        exit(1)
    else:
        exit(0)


if __name__ == "__main__":
    main()



from typing import Iterator, AsyncIterator

import pytest

from openai._streaming import SSEDecoder


@pytest.mark.asyncio
async def test_basic_async() -> None:
    async def body() -> AsyncIterator[str]:
        yield "event: completion"
        yield 'data: {"foo":true}'
        yield ""

    async for sse in SSEDecoder().aiter(body()):
        assert sse.event == "completion"
        assert sse.json() == {"foo": True}


def test_basic() -> None:
    def body() -> Iterator[str]:
        yield "event: completion"
        yield 'data: {"foo":true}'
        yield ""

    it = SSEDecoder().iter(body())
    sse = next(it)
    assert sse.event == "completion"
    assert sse.json() == {"foo": True}

    with pytest.raises(StopIteration):
        next(it)


def test_data_missing_event() -> None:
    def body() -> Iterator[str]:
        yield 'data: {"foo":true}'
        yield ""

    it = SSEDecoder().iter(body())
    sse = next(it)
    assert sse.event is None
    assert sse.json() == {"foo": True}

    with pytest.raises(StopIteration):
        next(it)


def test_event_missing_data() -> None:
    def body() -> Iterator[str]:
        yield "event: ping"
        yield ""

    it = SSEDecoder().iter(body())
    sse = next(it)
    assert sse.event == "ping"
    assert sse.data == ""

    with pytest.raises(StopIteration):
        next(it)


def test_multiple_events() -> None:
    def body() -> Iterator[str]:
        yield "event: ping"
        yield ""
        yield "event: completion"
        yield ""

    it = SSEDecoder().iter(body())

    sse = next(it)
    assert sse.event == "ping"
    assert sse.data == ""

    sse = next(it)
    assert sse.event == "completion"
    assert sse.data == ""

    with pytest.raises(StopIteration):
        next(it)


def test_multiple_events_with_data() -> None:
    def body() -> Iterator[str]:
        yield "event: ping"
        yield 'data: {"foo":true}'
        yield ""
        yield "event: completion"
        yield 'data: {"bar":false}'
        yield ""

    it = SSEDecoder().iter(body())

    sse = next(it)
    assert sse.event == "ping"
    assert sse.json() == {"foo": True}

    sse = next(it)
    assert sse.event == "completion"
    assert sse.json() == {"bar": False}

    with pytest.raises(StopIteration):
        next(it)
